import { DI } from '@microsoft/fast-foundation';
/**
 * The default `ServerRowDTOMapper`.
 * @public
 */
export class DefaultServerRowDTOMapper {
    constructor() {
        /**
         * Converts a server row DTO to an entity.
         * @param dto - The DTO to convert.
         * @returns The resulting entity.
         * @public
         */
        this.fromDTO = (dto) => ({
            serverRowMetadata: {
                operation: dto?.DETAILS?.OPERATION?.toLowerCase(),
                rowRef: dto?.DETAILS?.ROW_REF,
            },
        });
        /**
         * Converts a server row entity to a DTO.
         * @param entity - The entity to convert.
         * @returns The resulting DTO.
         * @public
         */
        this.toDTO = (entity) => ({
            DETAILS: {
                OPERATION: entity?.serverRowMetadata?.operation?.toUpperCase(),
                ROW_REF: entity?.serverRowMetadata?.rowRef,
            },
        });
    }
}
/**
 * A DI token used to obtain a `ServerRowDTOMapper` instance.
 * @public
 */
export const ServerRowDTOMapper = DI.createInterface((x) => x.singleton(DefaultServerRowDTOMapper));
